package com.dayou.controller;

import com.dayou.annotation.IgnoreAuth;
import com.dayou.dto.TaskRecordDTO;
import com.dayou.entity.Personal;
import com.dayou.utils.FileUploadUtils;
import com.dayou.workflow.annotation.FinishTask;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.RestController;
import com.dayou.controller.BaseController;
import com.dayou.service.IPersonalSceneService;
import com.dayou.entity.PersonalScene;
import com.dayou.common.RestResponse;
import org.springframework.web.bind.annotation.*;
import com.dayou.utils.ConvertUtil;
import com.dayou.utils.HttpKit;
import com.dayou.exception.ErrorCode;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.http.MediaType;
import org.springframework.web.multipart.MultipartFile;

import javax.validation.Valid;

import static com.dayou.exception.ErrorCode.DEFAULTERROR;
import static com.dayou.utils.MimeTypeUtils.IMAGE_EXTENSION;

/**
 * 个贷实勘表
 *
 * @author wucl
 * @since 2024-03-01
 */
@RestController
@RequestMapping("personalScene")
@Slf4j
public class PersonalSceneController extends BaseController {
    @Autowired
    private IPersonalSceneService personalSceneService;

    /**
    * 个贷实勘表列表
    */
    @GetMapping("")
    public RestResponse<Page<PersonalScene>> page(PersonalScene personalScene, Page page){
        Page<PersonalScene> pages=personalSceneService.selectPage(page,personalScene);
        return RestResponse.data(pages);
    }

    /**
     * 个贷实勘表详情
     */
    @GetMapping("/{personalId}")
    public RestResponse<PersonalScene> detail(@PathVariable Long personalId){
        PersonalScene xPersonalScene =personalSceneService.detail(personalId);
        return RestResponse.data(xPersonalScene);
     }

    /**
     * 个贷实勘表新增
     */
    @PostMapping("")
    public RestResponse<Boolean> save(@RequestBody PersonalScene personalScene) {
        Boolean ret = personalSceneService.add(personalScene);
        return RestResponse.data(ret);
    }

    /**
     * 个贷实勘表更新
     */
    @PutMapping("")
    public RestResponse<Boolean> update(@RequestBody PersonalScene personalScene) {
        Boolean ret = personalSceneService.update(personalScene);
        return RestResponse.data(ret);
    }

    /**
     * 个贷实勘表删除
     */
    @DeleteMapping("/{id}")
    public RestResponse<Boolean> delete(@PathVariable Long id) {
        Boolean ret = personalSceneService.delete(id);
        return RestResponse.data(ret);
    }

    /**
     * 个贷业务订单更新
     */
    @FinishTask
    @PutMapping("/scene")
    public RestResponse<Boolean> saveSceneInfo(@RequestBody @Valid TaskRecordDTO<PersonalScene> taskRecordDTO) {
        Boolean ret = personalSceneService.saveSceneInfo(taskRecordDTO);
        return RestResponse.data(ret);
    }

    @IgnoreAuth
    @PostMapping("/upload/{type}")
    public RestResponse upload(@PathVariable("type")Long type, MultipartFile file) {
        try {
            // 上传文件路径
            String filePath = dfsConfig.getPath();
            // 上传并返回新文件名称
            String fileName = null;
            fileName = FileUploadUtils.uploadImage(filePath, file,IMAGE_EXTENSION,null);
            String url = dfsConfig.getDomain() + fileName;
            Map map = new HashMap();
            map.put("fileName", fileName);
            map.put("url", url);
            map.put("type", type);
            return RestResponse.data(map);
        } catch (Exception e) {
            log.error("upload error", e);
            ErrorCode.throwBusinessException(DEFAULTERROR);
        }

        return RestResponse.error();
    }

}

